==> cscec5b-wzxt-api-3.0.0-20210624.112717-250-sources.jar: com/ejianc/business/wzxt/vo/ExitDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 退场单明细
 * 
 * @author generator
 * 
 */
public class ExitDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long exitId; // 退场主键ID
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialSourceId; // 物资来源主键
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别
    private java.lang.String materialTypeName; // 物资类别名称
    private java.lang.String materialCode; // 物料编码
    private java.lang.String unit; // 单位
    private java.lang.String spec; // 规格型号
    private java.lang.String memo; // 备注
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date stopDate; // 止租日
    private java.lang.String def1; // 
    private java.lang.String def2; // 
    private java.lang.String def3; // 
    private java.lang.String def4; // 
    private java.lang.String def5; // 
    private java.math.BigDecimal applyNums; // 申请退场数量
    private java.math.BigDecimal exitNums; // 本次退场数量
    private java.math.BigDecimal exitNumsSum; // 累计退场数量
    private java.lang.Integer type; // 行类型0-物资档案，1-验收，2-申请
    

    /**
     * 退场主键ID
     */
    public java.lang.Long getExitId() {
        return exitId;
    }

    /**
     * 退场主键ID
     */
    public void setExitId(java.lang.Long exitId) {
        this.exitId = exitId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资来源主键
     */
    public java.lang.String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源主键
     */
    public void setMaterialSourceId(java.lang.String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 止租日
     */
    public java.util.Date getStopDate() {
        return stopDate;
    }

    /**
     * 止租日
     */
    public void setStopDate(java.util.Date stopDate) {
        this.stopDate = stopDate;
    }
    /**
     * 
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }
    /**
     * 申请退场数量
     */
    public java.math.BigDecimal getApplyNums() {
        return applyNums;
    }

    /**
     * 申请退场数量
     */
    public void setApplyNums(java.math.BigDecimal applyNums) {
        this.applyNums = applyNums;
    }
    /**
     * 本次退场数量
     */
    public java.math.BigDecimal getExitNums() {
        return exitNums;
    }

    /**
     * 本次退场数量
     */
    public void setExitNums(java.math.BigDecimal exitNums) {
        this.exitNums = exitNums;
    }
    /**
     * 累计退场数量
     */
    public java.math.BigDecimal getExitNumsSum() {
        return exitNumsSum;
    }

    /**
     * 累计退场数量
     */
    public void setExitNumsSum(java.math.BigDecimal exitNumsSum) {
        this.exitNumsSum = exitNumsSum;
    }
    /**
     * 行类型0-物资档案，1-验收，2-申请
     */
    public java.lang.Integer getType() {
        return type;
    }

    /**
     * 行类型0-物资档案，1-验收，2-申请
     */
    public void setType(java.lang.Integer type) {
        this.type = type;
    }
    
}

==> cscec5b-wzxt-api-3.0.0-20210803.083941-296-sources.jar: com/ejianc/business/wzxt/vo/ExitDetailVO.java <==
package com.ejianc.business.wzxt.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 退场单明细
 * 
 * @author generator
 * 
 */
public class ExitDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long exitId; // 退场主键ID
    private java.lang.Long materialId; // 物资主键
    private java.lang.String materialSourceId; // 物资来源主键
    private java.lang.String materialName; // 物资名称
    private java.lang.Long materialTypeId; // 物资类别
    private java.lang.String materialTypeName; // 物资类别名称
    private java.lang.String materialCode; // 物料编码
    private java.lang.String unit; // 单位
    private java.lang.String spec; // 规格型号
    private java.lang.String memo; // 备注
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date stopDate; // 止租日
    private java.lang.String def1; // 
    private java.lang.String def2; // 
    private java.lang.String def3; // 
    private java.lang.String def4; // 
    private java.lang.String def5; // 
    private java.math.BigDecimal applyNums; // 申请退场数量
    private java.math.BigDecimal exitNums; // 本次退场数量
    private java.math.BigDecimal exitNumsSum; // 累计退场数量
    private java.math.BigDecimal checkNum; // 累计进场数量
    private java.lang.Integer type; // 行类型0-物资档案，1-验收，2-申请

    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }

    /**
     * 退场主键ID
     */
    public java.lang.Long getExitId() {
        return exitId;
    }

    /**
     * 退场主键ID
     */
    public void setExitId(java.lang.Long exitId) {
        this.exitId = exitId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资来源主键
     */
    public java.lang.String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源主键
     */
    public void setMaterialSourceId(java.lang.String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 止租日
     */
    public java.util.Date getStopDate() {
        return stopDate;
    }

    /**
     * 止租日
     */
    public void setStopDate(java.util.Date stopDate) {
        this.stopDate = stopDate;
    }
    /**
     * 
     */
    public java.lang.String getDef1() {
        return def1;
    }

    /**
     * 
     */
    public void setDef1(java.lang.String def1) {
        this.def1 = def1;
    }
    /**
     * 
     */
    public java.lang.String getDef2() {
        return def2;
    }

    /**
     * 
     */
    public void setDef2(java.lang.String def2) {
        this.def2 = def2;
    }
    /**
     * 
     */
    public java.lang.String getDef3() {
        return def3;
    }

    /**
     * 
     */
    public void setDef3(java.lang.String def3) {
        this.def3 = def3;
    }
    /**
     * 
     */
    public java.lang.String getDef4() {
        return def4;
    }

    /**
     * 
     */
    public void setDef4(java.lang.String def4) {
        this.def4 = def4;
    }
    /**
     * 
     */
    public java.lang.String getDef5() {
        return def5;
    }

    /**
     * 
     */
    public void setDef5(java.lang.String def5) {
        this.def5 = def5;
    }
    /**
     * 申请退场数量
     */
    public java.math.BigDecimal getApplyNums() {
        return applyNums;
    }

    /**
     * 申请退场数量
     */
    public void setApplyNums(java.math.BigDecimal applyNums) {
        this.applyNums = applyNums;
    }
    /**
     * 本次退场数量
     */
    public java.math.BigDecimal getExitNums() {
        return exitNums;
    }

    /**
     * 本次退场数量
     */
    public void setExitNums(java.math.BigDecimal exitNums) {
        this.exitNums = exitNums;
    }
    /**
     * 累计退场数量
     */
    public java.math.BigDecimal getExitNumsSum() {
        return exitNumsSum;
    }

    /**
     * 累计退场数量
     */
    public void setExitNumsSum(java.math.BigDecimal exitNumsSum) {
        this.exitNumsSum = exitNumsSum;
    }
    /**
     * 行类型0-物资档案，1-验收，2-申请
     */
    public java.lang.Integer getType() {
        return type;
    }

    /**
     * 行类型0-物资档案，1-验收，2-申请
     */
    public void setType(java.lang.Integer type) {
        this.type = type;
    }
    
}
